mlpy.tasks package
==================

.. automodule:: mlpy.tasks
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   mlpy.tasks.base
   mlpy.tasks.big_data
   mlpy.tasks.cluster
   mlpy.tasks.spatial
   mlpy.tasks.supervised
   mlpy.tasks.timeseries
